@@ -8,11 +8,11 @@
 #include "Config/Miscellaneous/BattleDataConfig.h"
 #include "Config/TaskData.h"
 #include "Controller/Controller.h"
+#include "MaaUtils/ImageIo.h"
+#include "MaaUtils/NoWarningCV.hpp"
+#include "MaaUtils/Time.hpp"
 #include "Task/ProcessTask.h"
-#include "Utils/ImageIo.hpp"
 #include "Utils/Logger.hpp"
-#include "Utils/NoWarningCV.h"
-#include "Utils/Time.hpp"
 #include "Vision/Battle/BattlefieldClassifier.h"
 #include "Vision/Battle/BattlefieldMatcher.h"
 #include "Vision/Matcher.h"
@@ -492,9 +492,7 @@ bool asst::BattleHelper::deploy_oper(const std::string& name, const Point& loc,
         // m_used_tiles.erase(pre_loc);
     }
 
-    m_used_tiles.emplace(loc, name);
-    m_battlefield_opers.emplace(name, loc);
-    m_last_use_skill_time.emplace(loc, std::chrono::steady_clock::time_point());
+    register_deployed_oper(name, loc);
     m_inst_helper.sleep(200); // 部署完会有 166 ms 的动画
 
     return true;
@@ -692,10 +690,8 @@ bool asst::BattleHelper::use_all_ready_skill(const cv::Mat& reusable)
         Log.info("Skill", name, "is ready");
 
         if (auto interval = now - last_use_time; min_frame_interval > interval) {
-            Log.info(
-                name,
-                "use skill too fast, interval time:",
-                std::to_string(std::chrono::duration_cast<std::chrono::milliseconds>(interval).count()) + " ms");
+            LogInfo << name << "use skill too fast, interval time:"
+                    << std::chrono::duration_cast<std::chrono::milliseconds>(interval).count() << " ms";
             continue;
         }
 
@@ -779,7 +775,7 @@ void asst::BattleHelper::save_map(const cv::Mat& image)
         suffix = "-" + std::to_string(m_camera_count);
     }
     std::vector<int> jpeg_params = { cv::IMWRITE_JPEG_QUALITY, 50, cv::IMWRITE_JPEG_OPTIMIZE, 1 };
-    asst::imwrite(MapRelativeDir / asst::utils::path(m_stage_name + suffix + ".jpeg"), draw, jpeg_params);
+    MAA_NS::imwrite(MapRelativeDir / asst::utils::path(m_stage_name + suffix + ".jpeg"), draw, jpeg_params);
 }
 
 bool asst::BattleHelper::click_oper_on_deployment(const std::string& name)
@@ -894,8 +890,8 @@ bool asst::BattleHelper::click_skill(bool keep_waiting)
 #ifdef ASST_DEBUG
     if (!top_view.empty()) {
         using namespace asst::utils::path_literals;
-        asst::imwrite(
-            asst::utils::path(std::format("debug/skill/{}_{}.png", m_stage_name, utils::format_now_for_filename())),
+        MAA_NS::imwrite(
+            asst::utils::path(std::format("debug/skill/{}_{}.png", m_stage_name, MAA_NS::format_now_for_filename())),
             top_view);
     }
 #endif
@@ -1047,6 +1043,13 @@ int asst::BattleHelper::elapsed_time()
     return static_cast<int>(elapsed_ms);
 }
 
+void asst::BattleHelper::register_deployed_oper(const std::string& name, const Point& loc)
+{
+    m_used_tiles.emplace(loc, name);
+    m_battlefield_opers.emplace(name, loc);
+    m_last_use_skill_time.emplace(loc, std::chrono::steady_clock::time_point());
+}
+
 void asst::BattleHelper::remove_cooling_from_battlefield(const battle::DeploymentOper& oper)
 {
     if (!oper.cooling) {
