@@ -49,7 +49,7 @@ bool asst::BattleFormationTask::_run()
     if (!parse_formation()) {
         return false;
     }
-    else if (compare_formation()) {
+    else if (compare_formation()) { // 与上一个作业的编队进行对比，相同则跳过
         Log.info(__FUNCTION__, "| Formation is the same as last time, skip");
         for (auto& [name, opers] : m_formation | std::views::values | std::views::join) {
             const auto& pair_it =
@@ -95,21 +95,20 @@ bool asst::BattleFormationTask::_run()
     }
 
     // 记录缺失干员组的数量
-    int missing_numbers = (int)std::ranges::count_if(
-        m_formation | std::views::transform([&](const auto& pair) { return pair.second; }) | std::views::join,
-        [&](const OperGroup& group) { return !has_oper_selected(group.second); });
+    auto missing_groups = std::ranges::views::filter(
+        m_formation | std::views::values /* 剔除职业 */ | std::views::join,
+        [&](const OperGroup& group) { return !has_oper_selected(group.second); }); // 拿到缺干员的组
+
+    int missing_numbers = (int)std::ranges::distance(missing_groups);
     // 在有且仅有一个缺失干员组时尝试寻找助战干员补齐编队
     if (use_suppprt_unit_when_needed() && missing_numbers == 1 && !m_used_support_unit) {
         // 之后再重构数据结构，先凑合用
         std::vector<battle::RequiredOper> required_opers;
+        const auto& missing_group = missing_groups.begin(); // 只有一个缺失干员组，直接取第一个
         for (const battle::OperUsage& oper :
-             m_formation | std::views::transform([&](const auto& pair) { return pair.second; }) /* 剔除职业 */ |
-                 std::views::join | /* 拿到缺干员的组 */ std::views::filter([&](const OperGroup& group) {
-                     return std::ranges::any_of(group.second, [&](const battle::OperUsage& oper) {
-                         return oper.status == battle::OperStatus::Missing;
-                     });
-                 }) |
-                 std::views::transform([&](const OperGroup& pair) { return pair.second; }) | std::views::join) {
+             missing_group->second | std::views::filter([&](const battle::OperUsage& oper) {
+                 return oper.status == battle::OperStatus::Missing;
+             })) {
             // 如果指定助战干员正好可以补齐编队，则只招募指定助战干员就好了，记得再次确认一下 skill
             // 如果编队里正好有【艾雅法拉 - 2】和 【艾雅法拉 - 3】呢？
             if (oper.name == m_specific_support_unit.name) {
@@ -125,8 +124,9 @@ bool asst::BattleFormationTask::_run()
         // 先退出去招募助战再回来，好蠢
         confirm_selection();
         Log.info(__FUNCTION__, "| Left quick formation scene");
-        if (add_support_unit(required_opers)) {
+        if (auto opt = add_support_unit(required_opers)) {
             m_used_support_unit = true;
+            m_opers_in_formation->emplace(*opt, missing_group->first);
         }
         // 再到快速编队页面
         if (!ProcessTask(*this, { "Formation-EnterQuickFormation" }).set_retry_times(3).run()) {
@@ -137,10 +137,10 @@ bool asst::BattleFormationTask::_run()
     }
 
     // 在尝试补齐编队后依然有缺失干员，自动编队失败
-    bool has_missing = !m_used_support_unit && std::ranges::any_of(m_formation, [&](const auto& pair) {
-        return std::ranges::any_of(pair.second /* role, groups */, [&](const OperGroup& group) {
-            return !has_oper_selected(group.second);
-        });
+    bool has_missing = std::ranges::any_of(missing_groups, [&](const auto& pair) {
+        // 缺失组未被助战补齐干员
+        return std::ranges::find_if(*m_opers_in_formation, [&](const auto& p) { return p.second == pair.first; }) ==
+               m_opers_in_formation->end();
     });
     if (has_missing) {
         report_missing_operators();
@@ -183,10 +183,10 @@ bool asst::BattleFormationTask::_run()
     confirm_selection();
 
     if (m_support_unit_usage == SupportUnitUsage::Specific && !m_used_support_unit) { // 使用指定助战干员
-        m_used_support_unit = add_support_unit({ m_specific_support_unit });
+        m_used_support_unit = add_support_unit({ m_specific_support_unit }).has_value();
     }
     else if (m_support_unit_usage == SupportUnitUsage::Random && !m_used_support_unit) { // 使用随机助战干员
-        m_used_support_unit = add_support_unit();
+        m_used_support_unit = add_support_unit().has_value();
     }
 
     return true;
@@ -286,13 +286,14 @@ bool asst::BattleFormationTask::add_formation(battle::Role role, const std::vect
             has_error = false;
         }
         else {
-            if (overall_swipe_times == m_missing_retry_times) {
+            if (overall_swipe_times >= m_missing_retry_times) {
                 for (auto& group : oper_group) {
                     if (has_oper_selected(group->second)) {
                         continue;
                     }
                     for (auto& oper : group->second) {
-                        if (oper.status == battle::OperStatus::Unchecked) {
+                        if (oper.status == battle::OperStatus::Unchecked &&
+                            !m_opers_in_formation->contains(oper.name)) {
                             oper.status = battle::OperStatus::Missing;
                         }
                     }
@@ -762,10 +763,10 @@ bool asst::BattleFormationTask::select_formation(int select_index, const cv::Mat
     // 第二组是名字最左边和最右边的一块区域
     // 右边比左边窄，暂定为左边 10*58
 
-    static const std::array<std::string, 4> select_formation_task = { "BattleSelectFormation1",
-                                                                      "BattleSelectFormation2",
-                                                                      "BattleSelectFormation3",
-                                                                      "BattleSelectFormation4" };
+    static const std::array<std::string, 4> select_formation_task { "BattleSelectFormation1",
+                                                                    "BattleSelectFormation2",
+                                                                    "BattleSelectFormation3",
+                                                                    "BattleSelectFormation4" };
 
     return ProcessTask { *this, { select_formation_task[select_index - 1] } }.set_reusable_image(img).run();
 }
@@ -778,7 +779,7 @@ bool asst::BattleFormationTask::is_formation_valid(const cv::Mat& img) const
     return task.run() && task.get_last_task_name() == valid_task;
 }
 
-bool asst::BattleFormationTask::add_support_unit(
+std::optional<std::string> asst::BattleFormationTask::add_support_unit(
     const std::vector<RequiredOper>& required_opers,
     const size_t max_refresh_times,
     const Friendship friendship)
@@ -792,8 +793,8 @@ bool asst::BattleFormationTask::add_support_unit(
 
     if (required_opers.empty()) { // 随机模式
         for (size_t refresh_times = 0; refresh_times <= max_refresh_times && !need_exit(); ++refresh_times) {
-            if (add_support_unit_from_support_list(support_list, required_opers, friendship)) {
-                return true;
+            if (auto opt = add_support_unit_from_support_list(support_list, required_opers, friendship)) {
+                return opt;
             }
             if (refresh_times < max_refresh_times) {
                 support_list.refresh_list();
@@ -821,8 +822,8 @@ bool asst::BattleFormationTask::add_support_unit(
             const std::vector<RequiredOper> filtered_required_opers(filtered_view.begin(), filtered_view.end());
 
             for (size_t refresh_times = 0; refresh_times <= max_refresh_times && !need_exit(); ++refresh_times) {
-                if (add_support_unit_from_support_list(support_list, filtered_required_opers, friendship)) {
-                    return true;
+                if (auto opt = add_support_unit_from_support_list(support_list, filtered_required_opers, friendship)) {
+                    return opt;
                 }
                 if (refresh_times < max_refresh_times) {
                     support_list.refresh_list();
@@ -834,10 +835,10 @@ bool asst::BattleFormationTask::add_support_unit(
     // 未找到符合要求的助战干员，手动退出助战列表
     Log.info(__FUNCTION__, "| Fail to find any qualified support operator");
     ProcessTask(*this, { "Formation-AddSupportUnit-LeaveSupportList" }).run();
-    return false;
+    return std::nullopt;
 }
 
-bool asst::BattleFormationTask::add_support_unit_from_support_list(
+std::optional<std::string> asst::BattleFormationTask::add_support_unit_from_support_list(
     SupportList& support_list,
     const std::vector<RequiredOper>& required_opers,
     const Friendship friendship)
@@ -854,20 +855,20 @@ bool asst::BattleFormationTask::add_support_unit_from_support_list(
             return static_cast<int>(support_unit.friendship) >= static_cast<int>(friendship);
         });
         if (it == support_units.end()) {
-            return false;
+            return std::nullopt;
         }
 
         const size_t support_unit_index = std::distance(support_units.begin(), it);
         if (!support_list.select_support_unit(support_unit_index)) {
-            return false;
+            return std::nullopt;
         }
 
         if (!support_list.confirm_to_use_support_unit()) {
             support_list.leave_support_unit_detail_panel();
-            return false;
+            return std::nullopt;
         }
 
-        return true;
+        return it->name;
     }
 
     for (const RequiredOper& required_oper : required_opers) {
@@ -900,9 +901,10 @@ bool asst::BattleFormationTask::add_support_unit_from_support_list(
                 support_list.leave_support_unit_detail_panel();
                 continue;
             }
-            return true;
+
+            return it->name;
         }
     }
 
-    return false;
+    return std::nullopt;
 }
